package main

import (
	"log/slog"
	"os"

	"git.nakama.town/fmartingr/butterrobot/internal/app"
	"git.nakama.town/fmartingr/butterrobot/internal/config"
)

func main() {
	// Initialize logger
	logger := slog.New(slog.NewTextHandler(os.Stdout, nil))

	// Load configuration
	cfg, err := config.Load()
	if err != nil {
		logger.Error("Failed to load configuration", "error", err)
		os.Exit(1)
	}

	// Initialize and run application
	application, err := app.New(cfg, logger)
	if err != nil {
		logger.Error("Failed to initialize application", "error", err)
		os.Exit(1)
	}
	
	if err := application.Run(); err != nil {
		logger.Error("Application error", "error", err)
		os.Exit(1)
	}
}